==> haskell-wl-pprint-terminfo-3.7.1.4-92-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-3PhxV9szvO5LKsa6kn792K
key: wl-pprint-terminfo-3.7.1.4-3PhxV9szvO5LKsa6kn792K
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: 4a09263be6ddef519f8b5eec7b990716
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-3PhxV9szvO5LKsa6kn792K
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-7qtJAWPnxB2GWt0AaK9Dlo
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-95-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-GmDCbApEN9JBBa9SMNaosn
key: wl-pprint-terminfo-3.7.1.4-GmDCbApEN9JBBa9SMNaosn
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: 560ac843d1c4236cbd5e96278a1389e1
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-GmDCbApEN9JBBa9SMNaosn
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-9H3XhdNymKhKLqssj5cvFt
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
